Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2017-08-21 19:06:46 +0300
committerCampbell Barton <ideasman42@gmail.com>2017-08-21 19:06:46 +0300
commit7e8784925780642e9db4219cf10000228f775949 (patch)
tree35d6337135ff2af1232ff3e3fbcb3edfecb50310 /source/blender/windowmanager/manipulators/intern/wm_manipulator_group.c
parentbe89b95e983566a74e72ab51fddacee49b808869 (diff)
Cleanup: rename manipulator API functions
- WM_manipulatorgrouptype_remove- > free - WM_manipulator_group -> WM_manipulator_group_type Naming here is still a bit confusing, now at least free/remove are differentiated.
Diffstat (limited to 'source/blender/windowmanager/manipulators/intern/wm_manipulator_group.c')
-rw-r--r--source/blender/windowmanager/manipulators/intern/wm_manipulator_group.c35
1 files changed, 18 insertions, 17 deletions
diff --git a/source/blender/windowmanager/manipulators/intern/wm_manipulator_group.c b/source/blender/windowmanager/manipulators/intern/wm_manipulator_group.c
index 87a5ee11d18..4ace8695555 100644
--- a/source/blender/windowmanager/manipulators/intern/wm_manipulator_group.c
+++ b/source/blender/windowmanager/manipulators/intern/wm_manipulator_group.c
@@ -683,7 +683,7 @@ void wm_manipulatorgrouptype_setup_keymap(
*
* \note In context of manipulator API these names are a bit misleading,
* but for general use terms its OK.
* `WM_manipulator_group_add` would be more correctly called:
* `WM_manipulatormaptype_grouptype_reference_link`
* but for general purpose API this is too detailed & annoying.
*
@@ -691,7 +691,7 @@ void wm_manipulatorgrouptype_setup_keymap(
*
* \{ */
-void WM_manipulator_group_add_ptr_ex(
+void WM_manipulator_group_type_add_ptr_ex(
wmManipulatorGroupType *wgt,
wmManipulatorMapType *mmap_type)
{
@@ -700,63 +700,64 @@ void WM_manipulator_group_add_ptr_ex(
WM_manipulatorconfig_update_tag_init(mmap_type, wgt);
}
-void WM_manipulator_group_add_ptr(
+void WM_manipulator_group_type_add_ptr(
wmManipulatorGroupType *wgt)
{
wmManipulatorMapType *mmap_type = WM_manipulatormaptype_ensure(&wgt->mmap_params);
- WM_manipulator_group_add_ptr_ex(wgt, mmap_type);
+ WM_manipulator_group_type_add_ptr_ex(wgt, mmap_type);
}
-void WM_manipulator_group_add(const char *idname)
+void WM_manipulator_group_type_add(const char *idname)
{
wmManipulatorGroupType *wgt = WM_manipulatorgrouptype_find(idname, false);
BLI_assert(wgt != NULL);
- WM_manipulator_group_add_ptr(wgt);
+ WM_manipulator_group_type_add_ptr(wgt);
}
-void WM_manipulator_group_remove_ptr_ex(
+
+void WM_manipulator_group_type_remove_ptr_ex(
struct Main *bmain, wmManipulatorGroupType *wgt,
wmManipulatorMapType *mmap_type)
{
WM_manipulatormaptype_group_unlink(NULL, bmain, mmap_type, wgt);
- WM_manipulatorgrouptype_remove_ptr(wgt);
+ WM_manipulatorgrouptype_free_ptr(wgt);
}
-void WM_manipulator_group_remove_ptr(
+void WM_manipulator_group_type_remove_ptr(
struct Main *bmain, wmManipulatorGroupType *wgt)
{
wmManipulatorMapType *mmap_type = WM_manipulatormaptype_ensure(&wgt->mmap_params);
- WM_manipulator_group_remove_ptr_ex(bmain, wgt, mmap_type);
+ WM_manipulator_group_type_remove_ptr_ex(bmain, wgt, mmap_type);
}
-void WM_manipulator_group_remove(struct Main *bmain, const char *idname)
+void WM_manipulator_group_type_remove(struct Main *bmain, const char *idname)
{
wmManipulatorGroupType *wgt = WM_manipulatorgrouptype_find(idname, false);
BLI_assert(wgt != NULL);
- WM_manipulator_group_remove_ptr(bmain, wgt);
+ WM_manipulator_group_type_remove_ptr(bmain, wgt);
}
/* delayed versions */
-void WM_manipulator_group_remove_ptr_delayed_ex(
+void WM_manipulator_group_type_remove_ptr_delayed_ex(
wmManipulatorGroupType *wgt,
wmManipulatorMapType *mmap_type)
{
WM_manipulatorconfig_update_tag_remove(mmap_type, wgt);
}
-void WM_manipulator_group_remove_ptr_delayed(
+void WM_manipulator_group_type_remove_ptr_delayed(
wmManipulatorGroupType *wgt)
{
wmManipulatorMapType *mmap_type = WM_manipulatormaptype_ensure(&wgt->mmap_params);
- WM_manipulator_group_remove_ptr_delayed_ex(wgt, mmap_type);
+ WM_manipulator_group_type_remove_ptr_delayed_ex(wgt, mmap_type);
}
-void WM_manipulator_group_remove_delayed(const char *idname)
+void WM_manipulator_group_type_remove_delayed(const char *idname)
{
wmManipulatorGroupType *wgt = WM_manipulatorgrouptype_find(idname, false);
BLI_assert(wgt != NULL);
- WM_manipulator_group_remove_ptr_delayed(wgt);
+ WM_manipulator_group_type_remove_ptr_delayed(wgt);
}
/** \} */
@@ -683,7 +683,7 @@ void wm_manipulatorgrouptype_setup_keymap(
* \note In context of manipulator API these names are a bit misleading,
* but for general use terms its OK.
- * `WM_manipulator_group_add` would be more correctly called:
+ * `WM_manipulator_group_type_add` would be more correctly called:
* `WM_manipulatormaptype_grouptype_reference_link`
* but for general purpose API this is too detailed & annoying.